var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import exceptionalError from 'exceptionalhandler';
import * as shopAPI from './shopify.api.js';
import * as shopUtils from './shopify.utils.js';
export function createPriceRule(ruleName, usageLimit, expiryDays, target, discountType, discountAmount) {
    return __awaiter(this, void 0, void 0, function* () {
        let newPriceRule = new shopAPI.shopify.rest.PriceRule({ session: shopAPI.shopSession });
        const now = new Date();
        if (shopUtils.isValEmpty(ruleName)) {
            throw new exceptionalError("Name is required");
        }
        if (shopUtils.isValEmpty(usageLimit) || typeof usageLimit !== 'number' || usageLimit <= 0) {
            throw new exceptionalError("usageLimit must be a number > 0");
        }
        if (shopUtils.isValEmpty(expiryDays) || typeof expiryDays !== 'number' || expiryDays <= 0) {
            throw new exceptionalError("expiryDays must be a number > 0");
        }
        if (shopUtils.isValEmpty(discountAmount) || typeof discountAmount !== 'number' || discountAmount <= 0) {
            throw new exceptionalError("Discount amount must be a number > 0");
        }
        newPriceRule.title = ruleName;
        newPriceRule.usage_limit = usageLimit;
        newPriceRule.customer_selection = "all";
        newPriceRule.target_selection = "all";
        newPriceRule.starts_at = now.toISOString();
        newPriceRule.ends_at = (new Date(Number(now) + expiryDays * 24 * 3600 * 1000)).toISOString();
        switch (target) {
            case "items":
                newPriceRule.target_type = "line_item";
                newPriceRule.allocation_method = "across";
                break;
            case "shipping":
                newPriceRule.target_type = "shipping_line";
                newPriceRule.allocation_method = "each";
                break;
            default:
                throw new exceptionalError(`Unknown target ${target}`);
        }
        switch (discountType) {
            case "absolute":
                newPriceRule.value_type = "fixed_amount";
                break;
            case "percent":
                if (discountAmount > 100) {
                    throw new exceptionalError("% Discount cannot be > 100%");
                }
                newPriceRule.value_type = "percentage";
                break;
            default:
                throw new exceptionalError(`Unknown discountType ${discountType}`);
        }
        newPriceRule.value = shopUtils.roundCashToString(-1 * discountAmount);
        yield shopAPI.submitObjectToAPI(newPriceRule);
        return (newPriceRule.id);
    });
}
export function createDiscountCode(priceRuleId, code) {
    return __awaiter(this, void 0, void 0, function* () {
        if (shopUtils.isValEmpty(priceRuleId) || typeof priceRuleId !== 'number' || priceRuleId <= 0) {
            throw new exceptionalError("priceRuleId must be a number > 0");
        }
        if (shopUtils.isValEmpty(code)) {
            throw new exceptionalError("Code is required");
        }
        if (code.match(/[^0-9a-z]/i)) {
            throw new exceptionalError("Alphanumeric chars only for code");
        }
        let newDiscount = new shopAPI.shopify.rest.DiscountCode({ session: shopAPI.shopSession });
        newDiscount.code = code;
        newDiscount.price_rule_id = priceRuleId;
        yield shopAPI.submitObjectToAPI(newDiscount);
        return true;
    });
}
