var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import '@shopify/shopify-api/adapters/node';
import * as shopConstants from './shopify.constants.js';
import { restResources } from './shopify.constants.js';
import * as logger from 'logger';
import exceptionalError from 'exceptionalhandler';
import util from 'util';
import * as dotenv from 'dotenv';
dotenv.config();
const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
let authProfiles;
if (isProduction) {
    authProfiles = {
        [shopConstants.shopBlueDriverUS]: {
            "host": process.env.PROD_SHOP_BD_US_HOST,
            "secret": process.env.PROD_SHOP_BD_US_SECRET,
            "token": process.env.PROD_SHOP_BD_US_TOKEN
        },
        [shopConstants.shopBlueDriverCA]: {
            "host": process.env.PROD_SHOP_BD_CA_HOST,
            "secret": process.env.PROD_SHOP_BD_CA_SECRET,
            "token": process.env.PROD_SHOP_BD_CA_TOKEN
        },
        [shopConstants.shopAccutrade]: {
            "host": process.env.PROD_SHOP_ACCUTRADE_HOST,
            "secret": process.env.PROD_SHOP_ACCUTRADE_SECRET,
            "token": process.env.PROD_SHOP_ACCUTRADE_TOKEN
        },
        [shopConstants.shopGeneralBDMax]: {
            "host": process.env.PROD_SHOP_BDMAX_HOST,
            "secret": process.env.PROD_SHOP_BDMAX_SECRET,
            "token": process.env.PROD_SHOP_BDMAX_TOKEN
        }
    };
}
else {
    authProfiles = {
        [shopConstants.shopBlueDriverUS]: {
            "host": process.env.DEV_SHOP_BD_US_HOST,
            "secret": process.env.DEV_SHOP_BD_US_SECRET,
            "token": process.env.DEV_SHOP_BD_US_TOKEN
        },
        [shopConstants.shopBlueDriverCA]: {
            "host": process.env.DEV_SHOP_BD_CA_HOST,
            "secret": process.env.DEV_SHOP_BD_CA_SECRET,
            "token": process.env.DEV_SHOP_BD_CA_TOKEN
        },
        [shopConstants.shopAccutrade]: {
            "host": process.env.DEV_SHOP_ACCUTRADE_HOST,
            "secret": process.env.DEV_SHOP_ACCUTRADE_SECRET,
            "token": process.env.DEV_SHOP_ACCUTRADE_TOKEN
        },
        [shopConstants.shopGeneralBDMax]: {
            "host": process.env.DEV_SHOP_BDMAX_HOST,
            "secret": process.env.DEV_SHOP_BDMAX_SECRET,
            "token": process.env.DEV_SHOP_BDMAX_TOKEN
        }
    };
}
export let shopify;
export let shopSession;
export function setShopifySession(shopInstanceName) {
    let auth;
    if (![shopConstants.shopBlueDriverUS, shopConstants.shopBlueDriverCA, shopConstants.shopAccutrade, shopConstants.shopGeneralBDMax, null].includes(shopInstanceName)) {
        throw new exceptionalError(`Invalid shop instance name: ${shopInstanceName}`);
    }
    if (!shopInstanceName) {
        shopify = null;
        shopSession = null;
    }
    else {
        //@ts-ignore
        auth = authProfiles[shopInstanceName];
        //@ts-ignore
        shopify = shopConstants.shopifyApi({
            apiSecretKey: auth.secret,
            apiVersion: shopConstants.apiVersion,
            adminApiAccessToken: auth.token,
            hostName: auth.host,
            isEmbeddedApp: false,
            isCustomStoreApp: true,
            logger: { level: 0 },
            restResources
        });
        shopSession = shopify.session.customAppSession(auth.host);
    }
}
export function submitObjectToAPI(object) {
    return __awaiter(this, void 0, void 0, function* () {
        let response;
        try {
            response = yield object.save({ update: true });
        }
        catch (e) {
            logger.info(util.inspect(e));
            throw new exceptionalError(parseHttpErrors(e));
        }
        return response;
    });
}
function parseHttpErrors(e) {
    let fullErrMsg = "";
    let errArr = [];
    if (e.hasOwnProperty("response")) {
        fullErrMsg = `Error ${e.response.code} | Error ${e.response.statusText}`;
        if (e.response.hasOwnProperty("body")) {
            let json;
            if (typeof e.response.body === 'string') {
                json = JSON.parse(e.response.body);
            }
            else {
                json = e.response.body;
            }
            if (json.hasOwnProperty("errors")) {
                if (Array.isArray(json.errors)) {
                    for (const errLine of json.errors) {
                        errArr.push(errLine);
                    }
                }
                else {
                    for (const [field, errs] of Object.entries(json.errors)) {
                        let errString = `${field}:`;
                        for (const err of errs) {
                            errString = `${errString}\n  -.${err}`;
                        }
                        errArr.push(errString);
                    }
                }
            }
        }
        if (errArr.length > 0) {
            fullErrMsg = `${fullErrMsg}\n${errArr.join(`\n`)}`;
        }
    }
    return fullErrMsg;
}
