var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
//@ts-nocheck
import * as shopConstants from '../shopify.constants.js';
import * as shopAPI from '../shopify.api.js';
import HttpRequestMock from 'http-request-mock';
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import { checkPost } from './cases/api.mocker.js';
import { createPriceRule, createDiscountCode } from '../shop.discounts.js';
const mocker = HttpRequestMock.setup();
describe('Test discount methods', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        shopAPI.setShopifySession(shopConstants.shopBlueDriverUS);
        mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { return checkPost(requestInfo); }));
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context(`Create price rules`, () => __awaiter(void 0, void 0, void 0, function* () {
        it('Validates', () => __awaiter(void 0, void 0, void 0, function* () {
            expect(createPriceRule()).to.be.rejectedWith("Name is required");
            expect(createPriceRule("Test Rule", "0")).to.be.rejectedWith("usageLimit must be a number > 0");
            expect(createPriceRule("Test Rule", 0)).to.be.rejectedWith("usageLimit must be a number > 0");
            expect(createPriceRule("Test Rule", 1, 0)).to.be.rejectedWith("expiryDays must be a number > 0");
            expect(createPriceRule("Test Rule", 1, "12-Dec-31")).to.be.rejectedWith("expiryDays must be a number > 0");
            expect(createPriceRule("Test Rule", 1, 3, "thing")).to.be.rejectedWith("Unknown target thing");
            expect(createPriceRule("Test Rule", 1, 3, "items", 5)).to.be.rejectedWith("Unknown discountType");
            expect(createPriceRule("Test Rule", 1, 3, "items", "percent", 101)).to.be.rejectedWith("% Discount cannot be > 100%");
            expect(createPriceRule("Test Rule", 1, 3, "items", "absolute", -101)).to.be.rejectedWith("Discount amount must be a number > 0");
        }));
        it('Works and returns the new priceId', () => __awaiter(void 0, void 0, void 0, function* () {
            let absTest = yield createPriceRule("Absolute Itme Rule", 4, 3, "items", "absolute", 101);
            expect(absTest).to.equal(123456789);
            let percentTest = yield createPriceRule("Percent Shipping Rule", 4, 3, "shipping", "percent", 100);
            expect(percentTest).to.equal(987654321);
        }));
    }));
    context('Create discount code for existing priceRules', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Validates', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect(createDiscountCode()).to.be.rejectedWith("priceRuleId must be a number > 0");
            yield expect(createDiscountCode("asdad")).to.be.rejectedWith("priceRuleId must be a number > 0");
            yield expect(createDiscountCode("9")).to.be.rejectedWith("priceRuleId must be a number > 0");
            yield expect(createDiscountCode(-5)).to.be.rejectedWith("priceRuleId must be a number > 0");
            yield expect(createDiscountCode(123456789)).to.be.rejectedWith("Code is required");
            yield expect(createDiscountCode(123456789, null)).to.be.rejectedWith("Code is required");
            yield expect(createDiscountCode(123456789, "")).to.be.rejectedWith("Code is required");
            yield expect(createDiscountCode(123456789, "QQ_FD")).to.be.rejectedWith("Alphanumeric chars only for code");
        }));
        it('Works', () => __awaiter(void 0, void 0, void 0, function* () {
            expect(yield createDiscountCode(123456789, "QQf5FD")).to.be.true;
        }));
    }));
}));
