//@ts-nocheck
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as shopConversions from '../shopify.conversions.js';
import * as shopConstants from '../shopify.constants.js';
import * as shopAPI from '../shopify.api.js';
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import * as dotenv from 'dotenv';
dotenv.config();
const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
import HttpRequestMock from 'http-request-mock';
import * as shopOrderCases from './cases/order.cases.js';
const mocker = HttpRequestMock.setup();
describe('Conver shop objects to nice friendly ones', () => __awaiter(void 0, void 0, void 0, function* () {
    let allOrders;
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.get(/\/orders.json/, shopOrderCases.orderJSON);
        mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { return checkPost(requestInfo); }));
        mocker.get(/fulfillment_orders.json/, () => {
            return shopOrderCases.fulfillmetOrderResp;
        });
        shopAPI.setShopifySession(shopConstants.shopBlueDriverUS);
        allOrders = yield shopAPI.shopify.rest.Order.all({
            session: shopAPI.shopSession,
            status: shopConstants.orderLookupNew
        });
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context('Catches issues', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Catches conflicting shipping_lines', () => __awaiter(void 0, void 0, void 0, function* () {
            let testOrder = allOrders.data[1];
            testOrder.shipping_lines.push({
                "id": 1234551,
                "carrier_identifier": "650f1a14fa979ec5c74d063e968411d4",
                "code": "Priority",
                "delivery_category": null,
                "discounted_price": "6.90",
                "discounted_price_set": {
                    "shop_money": {
                        "amount": "6.90",
                        "currency_code": "USD"
                    },
                    "presentment_money": {
                        "amount": "6.90",
                        "currency_code": "USD"
                    }
                },
                "phone": null,
                "price": "6.90",
                "price_set": {
                    "shop_money": {
                        "amount": "6.90",
                        "currency_code": "USD"
                    },
                    "presentment_money": {
                        "amount": "6.90",
                        "currency_code": "USD"
                    }
                },
                "requested_fulfillment_service_id": null,
                "source": "shopify",
                "title": "Priority",
                "tax_lines": [],
                "discount_allocations": []
            });
            expect(() => { shopConversions.shopOrderToNiceOrder(testOrder); }).to.throw(`Shopify order 5410796667179 had conflicting shipping services Standard & Priority`);
        }));
        it('Falls back to default_address is shipping_address isnt set', () => __awaiter(void 0, void 0, void 0, function* () {
            let convertedResp = shopConversions.shopOrderToNiceOrder(shopOrderCases.orderMissingShippingAddress);
            expect(convertedResp.address).to.deep.equal({
                firstName: "P",
                lastName: "Sherman",
                name: "P Sherman",
                addressOne: '42 Wallaby Way',
                addressTwo: null,
                city: 'New Beith',
                province: 'QLD',
                country: 'AU',
                postalCode: '4124',
                phone: null,
                email: 'jordan.porter@repairify.com',
                company: null
            });
            expect(convertedResp.source).to.equal(shopConstants.sourceTypes.sub);
        }));
    }));
    context('Converts successfully', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Works', () => __awaiter(void 0, void 0, void 0, function* () {
            let baseShopOrder = allOrders.data[0];
            let convertedNiceOrder = shopConversions.shopOrderToNiceOrder(baseShopOrder);
            let expectedNiceOrder = {
                shopId: "5410798502187",
                created: new Date('2023-07-24T15:37:22-02:30'),
                currency: "USD",
                orderNumber: 'BDMAX1002',
                notes: "thing1:val1,thing2:val2",
                orderStatusPage: 'https://d225d0-2.myshopify.com/79564472619/orders/65df58467838337f714b8d627174712b/authenticate?key=0f8fc7109ca288a774fa1aab7b51cafb',
                isTest: true,
                discountCodes: [{ code: 'FAKE30', amount: 9 }],
                address: {
                    firstName: "Chris",
                    lastName: "Nevin",
                    name: "Chris Nevin",
                    addressOne: '123 Something Street',
                    addressTwo: null,
                    city: 'Eminence',
                    province: 'MO',
                    country: 'US',
                    postalCode: '65466',
                    phone: '1 (236) 987-4055',
                    email: 'chris.nevin@repairify.com',
                    company: null
                },
                source: shopConstants.sourceTypes.shopify,
                items: [
                    {
                        lineId: '14130217124139',
                        qty: 5,
                        unitPrice: 150,
                        sku: 'LSB4',
                        title: 'BlueDriver Max',
                        variantId: '45813965848875',
                        variantTitle: null
                    }
                ],
                requestedShipping: 'Economy',
                money: {
                    subTotal: 750,
                    shipping: 0,
                    tax: 0,
                    discount: 0,
                    total: 750
                }
            };
            expect(convertedNiceOrder).to.deep.equal(expectedNiceOrder);
        }));
    }));
}));
