//@ts-nocheck
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as shop from '../shopify.js';
import * as shopOrderCases from './cases/order.cases.js';
import * as shopConverter from '../shopify.conversions.js';
import * as shopConstants from '../shopify.constants.js';
import * as shopAPI from '../shopify.api.js';
import * as shopOrderMethods from '../shopify.orders.js';
import { checkPost } from './cases/api.mocker.js';
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import * as dotenv from 'dotenv';
dotenv.config();
const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
import HttpRequestMock from 'http-request-mock';
const mocker = HttpRequestMock.setup();
describe('Test order functions', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.get(/\/orders.json/, shopOrderCases.orderJSON);
        mocker.get(/5413971558699.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, { status: 200 });
        mocker.get(/123456789.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, { status: 200 });
        mocker.get(/999.fulfillment_orders.json/, { "data": [] }, { status: 200 });
        mocker.post(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () { return checkPost(requestInfo); }));
        shopAPI.setShopifySession(shopConstants.shopBlueDriverUS);
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context('Test get nice orders', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Wroks', () => __awaiter(void 0, void 0, void 0, function* () {
            const allOrders = yield shopAPI.shopify.rest.Order.all({
                session: shopAPI.shopSession,
                status: shopConstants.orderLookupNew
            });
            const expected = shopConverter.shopOrderToNiceOrder(allOrders.data[2]);
            const formattedOrders = yield shop.getOrders(shopConstants.orderLookupNew);
            expect(formattedOrders[2]).to.deep.equal(expected);
        }));
    }));
    context('Test fulfullmentId retrieval', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Validates', () => __awaiter(void 0, void 0, void 0, function* () {
            const badId = "9999";
            yield expect(shopOrderMethods.getOrderFulfillmentIDs(badId)).to.be.rejectedWith('No match for orderID');
        }));
        it('Works', () => __awaiter(void 0, void 0, void 0, function* () {
            const goodId = "5413971558699";
            const expectMapping = [
                { lineItemId: "11", fulfillmentOrderId: "12121212" },
                { lineItemId: "22", fulfillmentOrderId: "2" },
                { lineItemId: "33", fulfillmentOrderId: "3" }
            ];
            const getIds = yield shopOrderMethods.getOrderFulfillmentIDs(goodId);
            expect(getIds).to.deep.equal(expectMapping);
        }));
    }));
    context('Test fulfillment_order submission', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Validates', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect(shopOrderMethods.addOrderTrackingDetails([], {})).to.be.rejectedWith('fulfillmentOrderIds must be an array with at least one fulfillment order ID');
            yield expect(shopOrderMethods.addOrderTrackingDetails(["123123a4123"], {})).to.be.rejectedWith('Fulfillment order IDs must be numeric (but as a string.. yeah)');
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123", 1231321], {})).to.be.rejectedWith('Fulfillment order IDs must be numeric (but as a string.. yeah)');
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], {})).to.be.rejectedWith(`Carrier and tracking number are mandatory fields`);
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], { trackingNumber: "asdad" })).to.be.rejectedWith(`Carrier and tracking number are mandatory fields`);
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], { carrier: "sdqdqewdqq" })).to.be.rejectedWith(`Carrier and tracking number are mandatory fields`);
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], { trackingNumber: "", carrier: "sdqdqewdqq" })).to.be.rejectedWith(`Carrier and tracking number are mandatory fields`);
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], { trackingNumber: "sdqdqewdqq", carrier: null })).to.be.rejectedWith(`Carrier and tracking number are mandatory fields`);
            yield expect(shopOrderMethods.addOrderTrackingDetails(["1231234123"], { trackingNumber: "sdqdqewdqq", carrier: "sdadsad", url: "www.vocm.com" })).to.be.rejectedWith(`Invalid tracking url`);
        }));
        it('Sends tracking info', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect(shopOrderMethods.addOrderTrackingDetails(["12345"], { trackingNumber: "someTracking", carrier: "USPS", url: "https://www.vocm.com/track?=someTracking" }, false)).not.to.be.rejected;
        }));
    }));
    context('Test order closure', () => __awaiter(void 0, void 0, void 0, function* () {
        it('Closes the order', () => __awaiter(void 0, void 0, void 0, function* () {
            yield expect(shopOrderMethods.closeOrder("12131231")).not.to.be.rejected;
        }));
    }));
    context('Test the ship order function', () => __awaiter(void 0, void 0, void 0, function* () {
        // it just combines other things so no validation requried
        it('Works', () => __awaiter(void 0, void 0, void 0, function* () {
            const allOrders = yield shopAPI.shopify.rest.Order.all({
                session: shopAPI.shopSession,
                status: shopConstants.orderLookupNew
            });
            const bigTestOrder = allOrders.data[2];
            let trackingDeets = {
                trackingNumber: "QQQQQ",
                carrier: "Canada Post"
            };
            yield expect(shop.shipOrder(bigTestOrder.id, trackingDeets)).not.to.be.rejected;
        }));
    }));
    context('Create new order', () => __awaiter(void 0, void 0, void 0, function* () {
        // Validations are in the conversion tests
        it('Creates an order and returns the shop ID', () => __awaiter(void 0, void 0, void 0, function* () {
            let newTestNiceOrder = {
                currency: "USD",
                orderNumber: "someNewOrderNumber",
                isTest: true,
                discountCodes: [],
                address: {
                    firstName: "firstName",
                    lastName: "lastName",
                    name: "firstName Q lastName",
                    addressOne: "1234 Something Street",
                    addressTwo: null,
                    city: "someVille",
                    province: "HI",
                    country: "JP",
                    postalCode: "12345",
                    phone: null,
                    email: "some@dude.com",
                    company: null
                },
                items: [
                    {
                        qty: 13,
                        unitPrice: 43.12,
                        sku: "someSku",
                        variantId: "123456",
                        variantTitle: "hello I am a variant!",
                        title: "yert"
                    }
                ],
                requestedShipping: "Express",
                money: {
                    subTotal: 560.56,
                    tax: 0,
                    shipping: 25,
                    discount: 585.56,
                    total: 0
                },
                notes: "Hello Friendo"
            };
            let shopId = yield shop.createOrder(newTestNiceOrder, "Priority");
            expect(shopId).to.equal("1073459971");
        }));
    }));
}));
