var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as shopConstants from '../shopify.constants.js';
import * as shopAPI from '../shopify.api.js';
import chai from 'chai';
import chaiAsPromised from "chai-as-promised";
const expect = chai.expect;
chai.use(chaiAsPromised);
import * as dotenv from 'dotenv';
dotenv.config();
const isProduction = (process.env.NODE_ENV === 'PRODUCTION');
import HttpRequestMock from 'http-request-mock';
const mocker = HttpRequestMock.setup();
describe('Testing multi-store functionality', () => __awaiter(void 0, void 0, void 0, function* () {
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        //  mocker.get(/\/orders.json/, shopOrderCases.orderJSON);
        //  mocker.get(/5413971558699.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, {status: 200});
        //  mocker.get(/123456789.fulfillment_orders.json/, shopOrderCases.fulfillmetOrderResp, {status: 200});
        //  mocker.get(/999.fulfillment_orders.json/, {"data": []}, {status: 200});        
        //  mocker.post(/./, async (requestInfo: RequestInfo) => {return checkPost(requestInfo);});
    }));
    after(() => __awaiter(void 0, void 0, void 0, function* () {
        mocker.reset();
    }));
    context('Errors', () => __awaiter(void 0, void 0, void 0, function* () {
        it.skip('Fails if no store is et first', () => __awaiter(void 0, void 0, void 0, function* () {
            expect(() => __awaiter(void 0, void 0, void 0, function* () {
                const allOrders = yield shopAPI.shopify.rest.Order.all({
                    session: shopAPI.shopSession,
                    status: shopConstants.orderLookupNew
                });
            })).to.throw;
        }));
        it('Fails with an invalid store name', () => __awaiter(void 0, void 0, void 0, function* () {
            expect(() => { shopAPI.setShopifySession("asdadad"); }).to.throw;
        }));
    }));
    context('Uses right store', () => __awaiter(void 0, void 0, void 0, function* () {
        let lastUrl = "";
        let lastToken = "";
        before(() => __awaiter(void 0, void 0, void 0, function* () {
            mocker.get(/./, (requestInfo) => __awaiter(void 0, void 0, void 0, function* () {
                lastUrl = requestInfo.url;
                //@ts-ignore
                lastToken = requestInfo.headers['x-shopify-access-token'];
                return { status: 200 };
            }));
        }));
        const stores = [shopConstants.shopAccutrade, shopConstants.shopBlueDriverCA, shopConstants.shopBlueDriverUS, shopConstants.shopGeneralBDMax];
        for (const store of stores) {
            it(`Sets deets for ${store} correctly`, () => __awaiter(void 0, void 0, void 0, function* () {
                shopAPI.setShopifySession(store);
                yield shopAPI.shopify.rest.Order.all({
                    session: shopAPI.shopSession,
                    status: shopConstants.orderLookupNew
                });
                switch (store) {
                    case shopConstants.shopBlueDriverCA:
                        expect(lastToken).to.equal('bdcatoken');
                        expect(lastUrl).to.include('fakebdca.myshopify.com');
                        break;
                    case shopConstants.shopBlueDriverUS:
                        expect(lastToken).to.equal('bdustoken');
                        expect(lastUrl).to.include('fakebdus.myshopify.com');
                        break;
                    case shopConstants.shopAccutrade:
                        expect(lastToken).to.equal('accutradetoken');
                        expect(lastUrl).to.include('fakeaccutrade.myshopify.com');
                        break;
                    case shopConstants.shopAccutrade:
                        expect(lastToken).to.equal('bdmaxtoken');
                        expect(lastUrl).to.include('fakebdmax.myshopify.com');
                        break;
                }
            }));
        }
    }));
}));
